Add include guards to all boost includes, as qt's moc trips
over nested BOOST_JOIN macros:
* /usr/lib64/qt4/bin/moc @/var/tmp/portage/media-gfx/scantailor-0.9.11.1/work/scantailor-0.9.11.1_build/filters/output/PictureZoneEditor.h.moc_parameters
* /usr/include/boost/type_traits/detail/has_binary_operator.hp:50: Parse error at "BOOST_JOIN"
See also: https://bugs.gentoo.org/show_bug.cgi?id=574634

--- scantailor-0.9.11.1/compat/boost_multi_index_foreach_fix.h
+++ scantailor-0.9.11.1/compat/boost_multi_index_foreach_fix.h
@@ -19,9 +19,11 @@
 #ifndef BOOST_MULTI_INDEX_FOREACH_FIX_H_
 #define BOOST_MULTI_INDEX_FOREACH_FIX_H_
 
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
 #include <boost/mpl/bool.hpp>
 #include <boost/multi_index/sequenced_index.hpp>
+#endif
 
 // BOOST_FOREACH() in boost >= 1.47 has problems with gcc >= 4.6
 // These problems aren't specific to boost::multi_index,
--- scantailor-0.9.11.1/DebugImageView.h
+++ scantailor-0.9.11.1/DebugImageView.h
@@ -21,7 +21,9 @@
 
 #include "AutoRemovingFile.h"
 #include <QStackedWidget>
+#ifndef Q_MOC_RUN
 #include <boost/intrusive/list.hpp>
+#endif
 
 class QImage;
 
--- scantailor-0.9.11.1/Despeckle.cpp
+++ scantailor-0.9.11.1/Despeckle.cpp
@@ -24,7 +24,9 @@
 #include "imageproc/BinaryImage.h"
 #include "imageproc/ConnectivityMap.h"
 #include "imageproc/Connectivity.h"
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
+#endif
 #include <QtGlobal>
 #include <QImage>
 #include <QDebug>
--- scantailor-0.9.11.1/dewarping/Curve.cpp
+++ scantailor-0.9.11.1/dewarping/Curve.cpp
@@ -20,7 +20,9 @@
 #include "XmlMarshaller.h"
 #include "XmlUnmarshaller.h"
 #include "VecNT.h"
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
+#endif
 #include <QByteArray>
 #include <QDataStream>
 #include <QDomDocument>
--- scantailor-0.9.11.1/dewarping/CylindricalSurfaceDewarper.cpp
+++ scantailor-0.9.11.1/dewarping/CylindricalSurfaceDewarper.cpp
@@ -24,7 +24,9 @@
 #include <QLineF>
 #include <QtGlobal>
 #include <QDebug>
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
+#endif
 #include <algorithm>
 #include <math.h>
 #include <assert.h>
--- scantailor-0.9.11.1/dewarping/CylindricalSurfaceDewarper.h
+++ scantailor-0.9.11.1/dewarping/CylindricalSurfaceDewarper.h
@@ -22,7 +22,9 @@
 #include "HomographicTransform.h"
 #include "PolylineIntersector.h"
 #include "ArcLengthMapper.h"
+#ifndef Q_MOC_RUN
 #include <boost/array.hpp>
+#endif
 #include <vector>
 #include <utility>
 #include <QPointF>
--- scantailor-0.9.11.1/dewarping/DetectVertContentBounds.cpp
+++ scantailor-0.9.11.1/dewarping/DetectVertContentBounds.cpp
@@ -32,9 +32,11 @@
 #include <QColor>
 #include <Qt>
 #include <QtGlobal>
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
 #include <boost/lambda/lambda.hpp>
 #include <boost/lambda/bind.hpp>
+#endif
 #include <vector>
 #include <deque>
 #include <algorithm>
--- scantailor-0.9.11.1/dewarping/DistortionModelBuilder.cpp
+++ scantailor-0.9.11.1/dewarping/DistortionModelBuilder.cpp
@@ -39,7 +39,9 @@
 #include <QPen>
 #include <QColor>
 #include <QDebug>
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
+#endif
 #include <algorithm>
 #include <exception>
 #include <iterator>
--- scantailor-0.9.11.1/dewarping/DistortionModel.cpp
+++ scantailor-0.9.11.1/dewarping/DistortionModel.cpp
@@ -26,7 +26,9 @@
 #include <QString>
 #include <QDomDocument>
 #include <QDomElement>
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
+#endif
 #include <algorithm>
 
 namespace dewarping
--- scantailor-0.9.11.1/dewarping/TextLineRefiner.cpp
+++ scantailor-0.9.11.1/dewarping/TextLineRefiner.cpp
@@ -24,10 +24,12 @@
 #include "imageproc/GrayImage.h"
 #include "imageproc/GaussBlur.h"
 #include "imageproc/Sobel.h"
+#ifndef Q_MOC_RUN
 #include <boost/scoped_array.hpp>
 #include <boost/foreach.hpp>
 #include <boost/lambda/lambda.hpp>
 #include <boost/lambda/bind.hpp>
+#endif
 #include <QImage>
 #include <QPainter>
 #include <QPen>
--- scantailor-0.9.11.1/dewarping/TextLineTracer.cpp
+++ scantailor-0.9.11.1/dewarping/TextLineTracer.cpp
@@ -58,11 +58,13 @@
 #include <QPen>
 #include <QColor>
 #include <QtGlobal>
+#ifndef Q_MOC_RUN
 #include <boost/scoped_array.hpp>
 #include <boost/foreach.hpp>
 #include <boost/lambda/lambda.hpp>
 #include <boost/lambda/bind.hpp>
 #include <boost/lambda/if.hpp>
+#endif
 #include <algorithm>
 #include <set>
 #include <map>
--- scantailor-0.9.11.1/dewarping/TopBottomEdgeTracer.cpp
+++ scantailor-0.9.11.1/dewarping/TopBottomEdgeTracer.cpp
@@ -39,9 +39,11 @@
 #include <QColor>
 #include <QtGlobal>
 #include <QDebug>
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
 #include <boost/lambda/lambda.hpp>
 #include <boost/lambda/bind.hpp>
+#endif
 #include <limits>
 #include <algorithm>
 #include <math.h>
--- scantailor-0.9.11.1/dewarping/TowardsLineTracer.cpp
+++ scantailor-0.9.11.1/dewarping/TowardsLineTracer.cpp
@@ -23,9 +23,11 @@
 #include "imageproc/SEDM.h"
 #include <QRect>
 #include <QtGlobal>
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
 #include <boost/lambda/lambda.hpp>
 #include <boost/lambda/bind.hpp>
+#endif
 #include <algorithm>
 #include <math.h>
 #include <assert.h>
--- scantailor-0.9.11.1/EstimateBackground.cpp
+++ scantailor-0.9.11.1/EstimateBackground.cpp
@@ -42,9 +42,11 @@
 #include <QTransform>
 #include <QDebug>
 #include <Qt>
+#ifndef Q_MOC_RUN
 #include <boost/lambda/lambda.hpp>
 #include <boost/lambda/bind.hpp>
 #include <boost/lambda/control_structures.hpp>
+#endif
 #include <vector>
 #include <algorithm>
 #include <stdint.h>
--- scantailor-0.9.11.1/FileNameDisambiguator.cpp
+++ scantailor-0.9.11.1/FileNameDisambiguator.cpp
@@ -24,6 +24,7 @@
 #include <QDomDocument>
 #include <QDomElement>
 #include <QMutex>
+#ifndef Q_MOC_RUN
 #include <boost/multi_index_container.hpp>
 #include <boost/multi_index/ordered_index.hpp>
 #include <boost/multi_index/sequenced_index.hpp>
@@ -31,6 +32,7 @@
 #include <boost/multi_index/composite_key.hpp>
 #include <boost/lambda/lambda.hpp>
 #include <boost/foreach.hpp>
+#endif
 
 using namespace boost::multi_index;
 
--- scantailor-0.9.11.1/FileNameDisambiguator.h
+++ scantailor-0.9.11.1/FileNameDisambiguator.h
@@ -21,7 +21,9 @@
 
 #include "NonCopyable.h"
 #include "RefCountable.h"
+#ifndef Q_MOC_RUN
 #include <boost/function.hpp>
+#endif
 #include <memory>
 #include <set>
 
--- scantailor-0.9.11.1/filters/deskew/Filter.cpp
+++ scantailor-0.9.11.1/filters/deskew/Filter.cpp
@@ -27,8 +27,10 @@
 #include "PageId.h"
 #include "RelinkablePath.h"
 #include "AbstractRelinker.h"
+#ifndef Q_MOC_RUN
 #include <boost/lambda/lambda.hpp>
 #include <boost/lambda/bind.hpp>
+#endif
 #include <QString>
 #include <QObject>
 #include <QCoreApplication>
--- scantailor-0.9.11.1/filters/deskew/ImageView.cpp
+++ scantailor-0.9.11.1/filters/deskew/ImageView.cpp
@@ -31,7 +31,9 @@
 #include <QScrollBar>
 #include <QStyle>
 #include <Qt>
+#ifndef Q_MOC_RUN
 #include <boost/bind.hpp>
+#endif
 #include <algorithm>
 #include <math.h>
 
--- scantailor-0.9.11.1/filters/deskew/OptionsWidget.cpp
+++ scantailor-0.9.11.1/filters/deskew/OptionsWidget.cpp
@@ -24,7 +24,9 @@
 #include <Qt>
 #include <math.h>
 #include "ApplyDialog.h"
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
+#endif
 
 namespace deskew
 {
--- scantailor-0.9.11.1/filters/deskew/Settings.cpp
+++ scantailor-0.9.11.1/filters/deskew/Settings.cpp
@@ -21,7 +21,9 @@
 #include "RelinkablePath.h"
 #include "AbstractRelinker.h"
 #include <QMutexLocker>
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
+#endif
 
 namespace deskew
 {
--- scantailor-0.9.11.1/filters/fix_orientation/Filter.cpp
+++ scantailor-0.9.11.1/filters/fix_orientation/Filter.cpp
@@ -29,8 +29,10 @@
 #include "ProjectWriter.h"
 #include "XmlMarshaller.h"
 #include "XmlUnmarshaller.h"
+#ifndef Q_MOC_RUN
 #include <boost/lambda/lambda.hpp>
 #include <boost/lambda/bind.hpp>
+#endif
 #include <QString>
 #include <QObject>
 #include <QCoreApplication>
--- scantailor-0.9.11.1/filters/fix_orientation/OptionsWidget.cpp
+++ scantailor-0.9.11.1/filters/fix_orientation/OptionsWidget.cpp
@@ -24,7 +24,9 @@
 #include "ProjectPages.h"
 #include "ImageId.h"
 #include "PageId.h"
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
+#endif
 #include <vector>
 #include <assert.h>
 
--- scantailor-0.9.11.1/filters/fix_orientation/Settings.cpp
+++ scantailor-0.9.11.1/filters/fix_orientation/Settings.cpp
@@ -20,7 +20,9 @@
 #include "Utils.h"
 #include "RelinkablePath.h"
 #include "AbstractRelinker.h"
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
+#endif
 
 namespace fix_orientation
 {
--- scantailor-0.9.11.1/filters/output/ChangeDewarpingDialog.cpp
+++ scantailor-0.9.11.1/filters/output/ChangeDewarpingDialog.cpp
@@ -20,8 +20,10 @@
 #include "ChangeDewarpingDialog.h.moc"
 #include "PageSelectionAccessor.h"
 #include "QtSignalForwarder.h"
+#ifndef Q_MOC_RUN
 #include <boost/function.hpp>
 #include <boost/lambda/lambda.hpp>
+#endif
 
 namespace output
 {
--- scantailor-0.9.11.1/filters/output/ChangeDpiDialog.cpp
+++ scantailor-0.9.11.1/filters/output/ChangeDpiDialog.cpp
@@ -26,7 +26,9 @@
 #include <QMessageBox>
 #include <QLineEdit>
 #include <QDebug>
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
+#endif
 #include <algorithm>
 
 namespace output
--- scantailor-0.9.11.1/filters/output/DewarpingView.cpp
+++ scantailor-0.9.11.1/filters/output/DewarpingView.cpp
@@ -43,9 +43,11 @@
 #include <QColor>
 #include <Qt>
 #include <QDebug>
+#ifndef Q_MOC_RUN
 #include <boost/array.hpp>
 #include <boost/bind.hpp>
 #include <boost/foreach.hpp>
+#endif
 #include <vector>
 #include <stdexcept>
 
--- scantailor-0.9.11.1/filters/output/FillZoneEditor.cpp
+++ scantailor-0.9.11.1/filters/output/FillZoneEditor.cpp
@@ -39,8 +39,10 @@
 #include <QBrush>
 #include <QPen>
 #include <Qt>
+#ifndef Q_MOC_RUN
 #include <boost/bind.hpp>
 #include <boost/foreach.hpp>
+#endif
 #include <vector>
 #include <assert.h>
 
--- scantailor-0.9.11.1/filters/output/FillZoneEditor.h
+++ scantailor-0.9.11.1/filters/output/FillZoneEditor.h
@@ -32,7 +32,9 @@
 #include "EditableZoneSet.h"
 #include "ZoomHandler.h"
 #include "DragHandler.h"
+#ifndef Q_MOC_RUN
 #include <boost/function.hpp>
+#endif
 #include <QPoint>
 #include <QPointF>
 #include <QColor>
--- scantailor-0.9.11.1/filters/output/Filter.cpp
+++ scantailor-0.9.11.1/filters/output/Filter.cpp
@@ -27,8 +27,10 @@
 #include "ProjectReader.h"
 #include "ProjectWriter.h"
 #include "CacheDrivenTask.h"
+#ifndef Q_MOC_RUN
 #include <boost/lambda/lambda.hpp>
 #include <boost/lambda/bind.hpp>
+#endif
 #include <QString>
 #include <QObject>
 #include <QCoreApplication>
--- scantailor-0.9.11.1/filters/output/OptionsWidget.cpp
+++ scantailor-0.9.11.1/filters/output/OptionsWidget.cpp
@@ -31,7 +31,9 @@
 #include "../../Utils.h"
 #include "ScopedIncDec.h"
 #include "config.h"
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
+#endif
 #include <QtGlobal>
 #include <QVariant>
 #include <QColorDialog>
--- scantailor-0.9.11.1/filters/output/OutputGenerator.cpp
+++ scantailor-0.9.11.1/filters/output/OutputGenerator.cpp
@@ -61,9 +61,11 @@
 #include "imageproc/ConnectivityMap.h"
 #include "imageproc/InfluenceMap.h"
 #include "config.h"
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
 #include <boost/bind.hpp>
 #include <boost/shared_ptr.hpp>
+#endif
 #include <QImage>
 #include <QSize>
 #include <QPoint>
--- scantailor-0.9.11.1/filters/output/OutputGenerator.h
+++ scantailor-0.9.11.1/filters/output/OutputGenerator.h
@@ -26,7 +26,9 @@
 #include "DespeckleLevel.h"
 #include "DewarpingMode.h"
 #include "ImageTransformation.h"
+#ifndef Q_MOC_RUN
 #include <boost/function.hpp>
+#endif
 #include <QSize>
 #include <QRect>
 #include <QTransform>
--- scantailor-0.9.11.1/filters/output/PictureZoneEditor.cpp
+++ scantailor-0.9.11.1/filters/output/PictureZoneEditor.cpp
@@ -41,8 +41,10 @@
 #include <QPen>
 #include <QBrush>
 #include <Qt>
+#ifndef Q_MOC_RUN
 #include <boost/bind.hpp>
 #include <boost/foreach.hpp>
+#endif
 #include <assert.h>
 
 namespace output
--- scantailor-0.9.11.1/filters/output/Settings.cpp
+++ scantailor-0.9.11.1/filters/output/Settings.cpp
@@ -23,7 +23,9 @@
 #include "RelinkablePath.h"
 #include "AbstractRelinker.h"
 #include "../../Utils.h"
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
+#endif
 #include <Qt>
 #include <QColor>
 #include <QMutexLocker>
--- scantailor-0.9.11.1/filters/output/Task.cpp
+++ scantailor-0.9.11.1/filters/output/Task.cpp
@@ -58,8 +58,10 @@
 #include "ErrorWidget.h"
 #include "imageproc/BinaryImage.h"
 #include "imageproc/PolygonUtils.h"
+#ifndef Q_MOC_RUN
 #include <boost/bind.hpp>
 #include <boost/shared_ptr.hpp>
+#endif
 #include <QImage>
 #include <QString>
 #include <QObject>
--- scantailor-0.9.11.1/filters/page_layout/Filter.cpp
+++ scantailor-0.9.11.1/filters/page_layout/Filter.cpp
@@ -32,8 +32,10 @@
 #include "OrderByWidthProvider.h"
 #include "OrderByHeightProvider.h"
 #include "Utils.h"
+#ifndef Q_MOC_RUN
 #include <boost/lambda/lambda.hpp>
 #include <boost/lambda/bind.hpp>
+#endif
 #include <QRectF>
 #include <QSizeF>
 #include <QString>
--- scantailor-0.9.11.1/filters/page_layout/ImageView.cpp
+++ scantailor-0.9.11.1/filters/page_layout/ImageView.cpp
@@ -37,8 +37,10 @@
 #include <QColor>
 #include <QDebug>
 #include <Qt>
+#ifndef Q_MOC_RUN
 #include <boost/bind.hpp>
 #include <boost/lambda/lambda.hpp>
+#endif
 #include <algorithm>
 #include <math.h>
 #include <assert.h>
--- scantailor-0.9.11.1/filters/page_layout/OptionsWidget.cpp
+++ scantailor-0.9.11.1/filters/page_layout/OptionsWidget.cpp
@@ -25,7 +25,9 @@
 #include "PageInfo.h"
 #include "PageId.h"
 #include "imageproc/Constants.h"
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
+#endif
 #include <QPixmap>
 #include <QString>
 #include <assert.h>
--- scantailor-0.9.11.1/filters/page_layout/Settings.cpp
+++ scantailor-0.9.11.1/filters/page_layout/Settings.cpp
@@ -27,6 +27,7 @@
 #include <QSizeF>
 #include <QMutex>
 #include <QMutexLocker>
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
 #include <boost/multi_index_container.hpp>
 #include <boost/multi_index/ordered_index.hpp>
@@ -34,6 +35,7 @@
 #include <boost/multi_index/member.hpp>
 #include <boost/multi_index/mem_fun.hpp>
 #include <boost/multi_index/composite_key.hpp>
+#endif
 #include <algorithm>
 #include <functional> // for std::greater<>
 #include <vector>
--- scantailor-0.9.11.1/filters/page_split/Filter.cpp
+++ scantailor-0.9.11.1/filters/page_split/Filter.cpp
@@ -31,8 +31,10 @@
 #include "Params.h"
 #include "CacheDrivenTask.h"
 #include "OrthogonalRotation.h"
+#ifndef Q_MOC_RUN
 #include <boost/lambda/lambda.hpp>
 #include <boost/lambda/bind.hpp>
+#endif
 #include <QString>
 #include <QObject>
 #include <QCoreApplication>
--- scantailor-0.9.11.1/filters/page_split/ImageView.cpp
+++ scantailor-0.9.11.1/filters/page_split/ImageView.cpp
@@ -29,8 +29,10 @@
 #include <QColor>
 #include <QtGlobal>
 #include <QDebug>
+#ifndef Q_MOC_RUN
 #include <boost/bind.hpp>
 #include <boost/foreach.hpp>
+#endif
 #include <algorithm>
 
 namespace page_split
--- scantailor-0.9.11.1/filters/page_split/OptionsWidget.cpp
+++ scantailor-0.9.11.1/filters/page_split/OptionsWidget.cpp
@@ -27,7 +27,9 @@
 #include "ProjectPages.h"
 #include "ScopedIncDec.h"
 #include <QPixmap>
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
+#endif
 #include <assert.h>
 
 namespace page_split
--- scantailor-0.9.11.1/filters/page_split/PageLayout.cpp
+++ scantailor-0.9.11.1/filters/page_split/PageLayout.cpp
@@ -28,7 +28,9 @@
 #include <QTransform>
 #include <QDomElement>
 #include <QDomDocument>
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
+#endif
 #include <algorithm>
 #include <math.h>
 #include <assert.h>
--- scantailor-0.9.11.1/filters/page_split/PageLayoutEstimator.cpp
+++ scantailor-0.9.11.1/filters/page_split/PageLayoutEstimator.cpp
@@ -47,9 +47,11 @@
 #include "imageproc/Grayscale.h"
 #include "imageproc/GrayRasterOp.h"
 #include "imageproc/PolygonRasterizer.h"
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
 #include <boost/lambda/lambda.hpp>
 #include <boost/lambda/bind.hpp>
+#endif
 #include <QRect>
 #include <QRectF>
 #include <QSize>
--- scantailor-0.9.11.1/filters/page_split/Settings.cpp
+++ scantailor-0.9.11.1/filters/page_split/Settings.cpp
@@ -20,7 +20,9 @@
 #include "RelinkablePath.h"
 #include "AbstractRelinker.h"
 #include <QMutexLocker>
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
+#endif
 #include <assert.h>
 
 namespace page_split
--- scantailor-0.9.11.1/filters/page_split/UnremoveButton.h
+++ scantailor-0.9.11.1/filters/page_split/UnremoveButton.h
@@ -25,7 +25,9 @@
 #include <QPointF>
 #include <QPixmap>
 #include <QCoreApplication>
+#ifndef Q_MOC_RUN
 #include <boost/function.hpp>
+#endif
 
 namespace page_split
 {
--- scantailor-0.9.11.1/filters/page_split/VertLineFinder.cpp
+++ scantailor-0.9.11.1/filters/page_split/VertLineFinder.cpp
@@ -28,7 +28,9 @@
 #include "imageproc/MorphGradientDetect.h"
 #include "imageproc/HoughLineDetector.h"
 #include "imageproc/Constants.h"
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
+#endif
 #include <QLineF>
 #include <QSizeF>
 #include <QColor>
--- scantailor-0.9.11.1/filters/select_content/ContentBoxFinder.cpp
+++ scantailor-0.9.11.1/filters/select_content/ContentBoxFinder.cpp
@@ -42,7 +42,9 @@
 #include "imageproc/ConnectivityMap.h"
 #include "imageproc/InfluenceMap.h"
 #include "imageproc/SEDM.h"
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
+#endif
 #include <QRect>
 #include <QRectF>
 #include <QPolygonF>
--- scantailor-0.9.11.1/filters/select_content/Filter.cpp
+++ scantailor-0.9.11.1/filters/select_content/Filter.cpp
@@ -28,8 +28,10 @@
 #include "CacheDrivenTask.h"
 #include "OrderByWidthProvider.h"
 #include "OrderByHeightProvider.h"
+#ifndef Q_MOC_RUN
 #include <boost/lambda/lambda.hpp>
 #include <boost/lambda/bind.hpp>
+#endif
 #include <QString>
 #include <QObject>
 #include <QDomDocument>
--- scantailor-0.9.11.1/filters/select_content/ImageView.cpp
+++ scantailor-0.9.11.1/filters/select_content/ImageView.cpp
@@ -32,7 +32,9 @@
 #include <QCursor>
 #include <QDebug>
 #include <Qt>
+#ifndef Q_MOC_RUN
 #include <boost/bind.hpp>
+#endif
 #include <algorithm>
 
 namespace select_content
--- scantailor-0.9.11.1/filters/select_content/OptionsWidget.cpp
+++ scantailor-0.9.11.1/filters/select_content/OptionsWidget.cpp
@@ -22,7 +22,9 @@
 #include "Settings.h"
 #include "Params.h"
 #include "ScopedIncDec.h"
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
+#endif
 
 namespace select_content
 {
--- scantailor-0.9.11.1/filters/select_content/Settings.cpp
+++ scantailor-0.9.11.1/filters/select_content/Settings.cpp
@@ -21,7 +21,9 @@
 #include "RelinkablePath.h"
 #include "AbstractRelinker.h"
 #include <QMutexLocker>
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
+#endif
 
 namespace select_content
 {
--- scantailor-0.9.11.1/FixDpiDialog.cpp
+++ scantailor-0.9.11.1/FixDpiDialog.cpp
@@ -30,9 +30,11 @@
 #include <QColor>
 #include <Qt>
 #include <QDebug>
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
 #include <boost/lambda/lambda.hpp>
 #include <boost/lambda/bind.hpp>
+#endif
 #include <vector>
 #include <algorithm>
 #include <assert.h>
--- scantailor-0.9.11.1/foundation/DynamicPool.h
+++ scantailor-0.9.11.1/foundation/DynamicPool.h
@@ -20,8 +20,10 @@
 #define DYNAMIC_POOL_H_
 
 #include "NonCopyable.h"
+#ifndef Q_MOC_RUN
 #include <boost/intrusive/list.hpp>
 #include <boost/scoped_array.hpp>
+#endif
 #include <stddef.h>
 
 /**
--- scantailor-0.9.11.1/foundation/FastQueue.h
+++ scantailor-0.9.11.1/foundation/FastQueue.h
@@ -20,9 +20,11 @@
 #define FAST_QUEUE_H_
 
 #include "NonCopyable.h"
+#ifndef Q_MOC_RUN
 #include <boost/intrusive/list.hpp>
 #include <boost/type_traits/alignment_of.hpp>
 #include <boost/foreach.hpp>
+#endif
 #include <stddef.h>
 #include <stdint.h>
 #include <assert.h>
--- scantailor-0.9.11.1/foundation/Grid.h
+++ scantailor-0.9.11.1/foundation/Grid.h
@@ -19,7 +19,9 @@
 #ifndef GRID_H_
 #define GRID_H_
 
+#ifndef Q_MOC_RUN
 #include <boost/scoped_array.hpp>
+#endif
 
 template<typename Node>
 class Grid
--- scantailor-0.9.11.1/foundation/MatT.h
+++ scantailor-0.9.11.1/foundation/MatT.h
@@ -19,7 +19,9 @@
 #ifndef MAT_T_H_
 #define MAT_T_H_
 
+#ifndef Q_MOC_RUN
 #include <boost/scoped_array.hpp>
+#endif
 #include <stddef.h>
 #include <assert.h>
 
--- scantailor-0.9.11.1/foundation/PropertySet.cpp
+++ scantailor-0.9.11.1/foundation/PropertySet.cpp
@@ -21,7 +21,9 @@
 #include <QDomDocument>
 #include <QDomElement>
 #include <QString>
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
+#endif
 
 PropertySet::PropertySet(QDomElement const& el, PropertyFactory const& factory)
 {
--- scantailor-0.9.11.1/foundation/QtSignalForwarder.h
+++ scantailor-0.9.11.1/foundation/QtSignalForwarder.h
@@ -21,7 +21,9 @@
 
 #include "NonCopyable.h"
 #include <QObject>
+#ifndef Q_MOC_RUN
 #include <boost/function.hpp>
+#endif
 
 /**
  * \brief Connects to a Qt signal and forwards it to a boost::function.
--- scantailor-0.9.11.1/foundation/VecT.h
+++ scantailor-0.9.11.1/foundation/VecT.h
@@ -19,7 +19,9 @@
 #ifndef VEC_T_H_
 #define VEC_T_H_
 
+#ifndef Q_MOC_RUN
 #include <boost/scoped_array.hpp>
+#endif
 #include <stddef.h>
 #include <assert.h>
 
--- scantailor-0.9.11.1/ImageFileInfo.cpp
+++ scantailor-0.9.11.1/ImageFileInfo.cpp
@@ -17,8 +17,10 @@
 */
 
 #include "ImageFileInfo.h"
+#ifndef Q_MOC_RUN
 #include <boost/lambda/lambda.hpp>
 #include <boost/lambda/bind.hpp>
+#endif
 #include <algorithm>
 
 bool
--- scantailor-0.9.11.1/imageproc/ConnCompEraserExt.cpp
+++ scantailor-0.9.11.1/imageproc/ConnCompEraserExt.cpp
@@ -19,7 +19,9 @@
 #include "ConnCompEraserExt.h"
 #include "RasterOp.h"
 #include <QRect>
+#ifndef Q_MOC_RUN
 #include <boost/cstdint.hpp>
+#endif
 #include <string.h>
 #include <stddef.h>
 #include <assert.h>
--- scantailor-0.9.11.1/imageproc/ConnectivityMap.cpp
+++ scantailor-0.9.11.1/imageproc/ConnectivityMap.cpp
@@ -20,7 +20,9 @@
 #include "BinaryImage.h"
 #include "InfluenceMap.h"
 #include "BitOps.h"
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
+#endif
 #include <QImage>
 #include <QColor>
 #include <QDebug>
--- scantailor-0.9.11.1/imageproc/GaussBlur.cpp
+++ scantailor-0.9.11.1/imageproc/GaussBlur.cpp
@@ -22,8 +22,10 @@
 #include "GaussBlur.h"
 #include "GrayImage.h"
 #include "Constants.h"
+#ifndef Q_MOC_RUN
 #include <boost/lambda/lambda.hpp>
 #include <boost/lambda/bind.hpp>
+#endif
 #include <stdint.h>
 #include <math.h>
 
--- scantailor-0.9.11.1/imageproc/GaussBlur.h
+++ scantailor-0.9.11.1/imageproc/GaussBlur.h
@@ -24,7 +24,9 @@
 
 #include "ValueConv.h"
 #include <QSize>
+#ifndef Q_MOC_RUN
 #include <boost/scoped_array.hpp>
+#endif
 #include <iterator>
 #include <string.h>
 
--- scantailor-0.9.11.1/imageproc/HoughLineDetector.cpp
+++ scantailor-0.9.11.1/imageproc/HoughLineDetector.cpp
@@ -36,7 +36,9 @@
 #include <QColor>
 #include <QPainter>
 #include <QDebug>
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
+#endif
 #include <algorithm>
 #include <math.h>
 #include <stdint.h>
--- scantailor-0.9.11.1/imageproc/MaxWhitespaceFinder.cpp
+++ scantailor-0.9.11.1/imageproc/MaxWhitespaceFinder.cpp
@@ -19,7 +19,9 @@
 #include "MaxWhitespaceFinder.h"
 #include <QPoint>
 #include <QDebug>
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
+#endif
 #include <algorithm>
 #include <limits>
 #include <stddef.h>
--- scantailor-0.9.11.1/imageproc/Morphology.cpp
+++ scantailor-0.9.11.1/imageproc/Morphology.cpp
@@ -25,7 +25,9 @@
 #include <QSize>
 #include <QRect>
 #include <QDebug>
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
+#endif
 #include <vector>
 #include <stdexcept>
 #include <algorithm>
--- scantailor-0.9.11.1/imageproc/PolygonRasterizer.cpp
+++ scantailor-0.9.11.1/imageproc/PolygonRasterizer.cpp
@@ -26,7 +26,9 @@
 #include <QPointF>
 #include <QImage>
 #include <QtGlobal>
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
+#endif
 #include <vector>
 #include <iterator>
 #include <algorithm>
--- scantailor-0.9.11.1/imageproc/PolygonUtils.cpp
+++ scantailor-0.9.11.1/imageproc/PolygonUtils.cpp
@@ -20,7 +20,9 @@
 #include <QPolygonF>
 #include <QPointF>
 #include <QLineF>
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
+#endif
 #include <algorithm>
 #include <stddef.h>
 #include <math.h>
--- scantailor-0.9.11.1/imageproc/PolynomialSurface.cpp
+++ scantailor-0.9.11.1/imageproc/PolynomialSurface.cpp
@@ -24,7 +24,9 @@
 #include "Grayscale.h"
 #include "BitOps.h"
 #include <QDebug>
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
+#endif
 #include <stdexcept>
 #include <algorithm>
 #include <math.h>
--- scantailor-0.9.11.1/imageproc/RasterOp.h
+++ scantailor-0.9.11.1/imageproc/RasterOp.h
@@ -23,7 +23,9 @@
 #include <QPoint>
 #include <QRect>
 #include <QSize>
+#ifndef Q_MOC_RUN
 #include <boost/cstdint.hpp>
+#endif
 #include <stdexcept>
 #include <assert.h>
 
--- scantailor-0.9.11.1/imageproc/tests/main.cpp
+++ scantailor-0.9.11.1/imageproc/tests/main.cpp
@@ -22,4 +22,6 @@
 
 #define BOOST_AUTO_TEST_MAIN
 
+#ifndef Q_MOC_RUN
 #include <boost/test/auto_unit_test.hpp>
+#endif
--- scantailor-0.9.11.1/imageproc/tests/TestBinarize.cpp
+++ scantailor-0.9.11.1/imageproc/tests/TestBinarize.cpp
@@ -21,7 +21,9 @@
 #include "Utils.h"
 #include <QImage>
 #include <QSize>
+#ifndef Q_MOC_RUN
 #include <boost/test/auto_unit_test.hpp>
+#endif
 
 namespace imageproc
 {
--- scantailor-0.9.11.1/imageproc/tests/TestBinaryImage.cpp
+++ scantailor-0.9.11.1/imageproc/tests/TestBinaryImage.cpp
@@ -20,7 +20,9 @@
 #include "BWColor.h"
 #include "Utils.h"
 #include <QImage>
+#ifndef Q_MOC_RUN
 #include <boost/test/auto_unit_test.hpp>
+#endif
 #include <stdlib.h>
 
 namespace imageproc
--- scantailor-0.9.11.1/imageproc/tests/TestConnCompEraser.cpp
+++ scantailor-0.9.11.1/imageproc/tests/TestConnCompEraser.cpp
@@ -23,7 +23,9 @@
 #include <QImage>
 #include <list>
 #include <algorithm>
+#ifndef Q_MOC_RUN
 #include <boost/test/auto_unit_test.hpp>
+#endif
 
 namespace imageproc
 {
--- scantailor-0.9.11.1/imageproc/tests/TestConnCompEraserExt.cpp
+++ scantailor-0.9.11.1/imageproc/tests/TestConnCompEraserExt.cpp
@@ -25,7 +25,9 @@
 #include <QImage>
 #include <list>
 #include <algorithm>
+#ifndef Q_MOC_RUN
 #include <boost/test/auto_unit_test.hpp>
+#endif
 
 namespace imageproc
 {
--- scantailor-0.9.11.1/imageproc/tests/TestDentFinder.cpp
+++ scantailor-0.9.11.1/imageproc/tests/TestDentFinder.cpp
@@ -20,7 +20,9 @@
 #include "BinaryImage.h"
 #include "Utils.h"
 #include <QImage>
+#ifndef Q_MOC_RUN
 #include <boost/test/auto_unit_test.hpp>
+#endif
 
 namespace imageproc
 {
--- scantailor-0.9.11.1/imageproc/tests/TestGrayscale.cpp
+++ scantailor-0.9.11.1/imageproc/tests/TestGrayscale.cpp
@@ -19,7 +19,9 @@
 #include "Grayscale.h"
 #include "Utils.h"
 #include <QImage>
+#ifndef Q_MOC_RUN
 #include <boost/test/auto_unit_test.hpp>
+#endif
 #include <stdlib.h>
 
 namespace imageproc
--- scantailor-0.9.11.1/imageproc/tests/TestMorphology.cpp
+++ scantailor-0.9.11.1/imageproc/tests/TestMorphology.cpp
@@ -24,7 +24,9 @@
 #include <QImage>
 #include <QSize>
 #include <QPoint>
+#ifndef Q_MOC_RUN
 #include <boost/test/auto_unit_test.hpp>
+#endif
 
 namespace imageproc
 {
--- scantailor-0.9.11.1/imageproc/tests/TestOrthogonalRotation.cpp
+++ scantailor-0.9.11.1/imageproc/tests/TestOrthogonalRotation.cpp
@@ -21,7 +21,9 @@
 #include "Utils.h"
 #include <QImage>
 #include <QRect>
+#ifndef Q_MOC_RUN
 #include <boost/test/auto_unit_test.hpp>
+#endif
 
 namespace imageproc
 {
--- scantailor-0.9.11.1/imageproc/tests/TestPolygonRasterizer.cpp
+++ scantailor-0.9.11.1/imageproc/tests/TestPolygonRasterizer.cpp
@@ -32,7 +32,9 @@
 #include <QColor>
 #include <Qt>
 #include <math.h>
+#ifndef Q_MOC_RUN
 #include <boost/test/auto_unit_test.hpp>
+#endif
 
 namespace imageproc
 {
--- scantailor-0.9.11.1/imageproc/tests/TestRasterOp.cpp
+++ scantailor-0.9.11.1/imageproc/tests/TestRasterOp.cpp
@@ -20,7 +20,9 @@
 #include "BinaryImage.h"
 #include "Utils.h"
 #include <QImage>
+#ifndef Q_MOC_RUN
 #include <boost/test/auto_unit_test.hpp>
+#endif
 #include <vector>
 #include <stddef.h>
 #include <stdlib.h>
--- scantailor-0.9.11.1/imageproc/tests/TestReduceThreshold.cpp
+++ scantailor-0.9.11.1/imageproc/tests/TestReduceThreshold.cpp
@@ -20,7 +20,9 @@
 #include "BinaryImage.h"
 #include "Utils.h"
 #include <QImage>
+#ifndef Q_MOC_RUN
 #include <boost/test/auto_unit_test.hpp>
+#endif
 
 namespace imageproc
 {
--- scantailor-0.9.11.1/imageproc/tests/TestScale.cpp
+++ scantailor-0.9.11.1/imageproc/tests/TestScale.cpp
@@ -21,7 +21,9 @@
 #include "Utils.h"
 #include <QImage>
 #include <QSize>
+#ifndef Q_MOC_RUN
 #include <boost/test/auto_unit_test.hpp>
+#endif
 #include <stdint.h>
 #include <stdlib.h>
 #include <math.h>
--- scantailor-0.9.11.1/imageproc/tests/TestSEDM.cpp
+++ scantailor-0.9.11.1/imageproc/tests/TestSEDM.cpp
@@ -22,7 +22,9 @@
 #include "Utils.h"
 #include <iostream>
 #include <QImage>
+#ifndef Q_MOC_RUN
 #include <boost/test/auto_unit_test.hpp>
+#endif
 
 #include <math.h>
 
--- scantailor-0.9.11.1/imageproc/tests/TestSeedFill.cpp
+++ scantailor-0.9.11.1/imageproc/tests/TestSeedFill.cpp
@@ -25,7 +25,9 @@
 #include <QImage>
 #include <QSize>
 #include <QPoint>
+#ifndef Q_MOC_RUN
 #include <boost/test/auto_unit_test.hpp>
+#endif
 
 namespace imageproc
 {
--- scantailor-0.9.11.1/imageproc/tests/TestShear.cpp
+++ scantailor-0.9.11.1/imageproc/tests/TestShear.cpp
@@ -21,7 +21,9 @@
 #include "BWColor.h"
 #include "Utils.h"
 #include <QImage>
+#ifndef Q_MOC_RUN
 #include <boost/test/auto_unit_test.hpp>
+#endif
 
 namespace imageproc
 {
--- scantailor-0.9.11.1/imageproc/tests/TestSkewFinder.cpp
+++ scantailor-0.9.11.1/imageproc/tests/TestSkewFinder.cpp
@@ -24,7 +24,9 @@
 #include <QTransform>
 #include <QColor>
 #include <QString>
+#ifndef Q_MOC_RUN
 #include <boost/test/auto_unit_test.hpp>
+#endif
 #include <math.h>
 #include <stdlib.h>
 
--- scantailor-0.9.11.1/imageproc/tests/TestSlicedHistogram.cpp
+++ scantailor-0.9.11.1/imageproc/tests/TestSlicedHistogram.cpp
@@ -22,7 +22,9 @@
 #include <QImage>
 #include <stdexcept>
 #include <stddef.h>
+#ifndef Q_MOC_RUN
 #include <boost/test/auto_unit_test.hpp>
+#endif
 
 namespace imageproc
 {
--- scantailor-0.9.11.1/imageproc/tests/TestTransform.cpp
+++ scantailor-0.9.11.1/imageproc/tests/TestTransform.cpp
@@ -21,7 +21,9 @@
 #include "Utils.h"
 #include <QImage>
 #include <QSize>
+#ifndef Q_MOC_RUN
 #include <boost/test/auto_unit_test.hpp>
+#endif
 #include <stdint.h>
 #include <stdlib.h>
 #include <math.h>
--- scantailor-0.9.11.1/interaction/DraggableLineSegment.h
+++ scantailor-0.9.11.1/interaction/DraggableLineSegment.h
@@ -22,7 +22,9 @@
 #include "DraggableObject.h"
 #include <QPointF>
 #include <QLineF>
+#ifndef Q_MOC_RUN
 #include <boost/function.hpp>
+#endif
 
 class ObjectDragHandler;
 
--- scantailor-0.9.11.1/interaction/DraggableObject.h
+++ scantailor-0.9.11.1/interaction/DraggableObject.h
@@ -21,7 +21,9 @@
 
 #include "InteractionState.h"
 #include "Proximity.h"
+#ifndef Q_MOC_RUN
 #include <boost/function.hpp>
+#endif
 
 class ObjectDragHandler;
 class QPoint;
--- scantailor-0.9.11.1/interaction/DraggablePoint.h
+++ scantailor-0.9.11.1/interaction/DraggablePoint.h
@@ -21,7 +21,9 @@
 
 #include "DraggableObject.h"
 #include <QPointF>
+#ifndef Q_MOC_RUN
 #include <boost/function.hpp>
+#endif
 
 class DraggablePoint : public DraggableObject
 {
--- scantailor-0.9.11.1/interaction/DragHandler.h
+++ scantailor-0.9.11.1/interaction/DragHandler.h
@@ -25,7 +25,9 @@
 #include "InteractionState.h"
 #include <QPoint>
 #include <QCoreApplication>
+#ifndef Q_MOC_RUN
 #include <boost/function.hpp>
+#endif
 
 class ImageViewBase;
 
--- scantailor-0.9.11.1/interaction/InteractionHandler.cpp
+++ scantailor-0.9.11.1/interaction/InteractionHandler.cpp
@@ -24,9 +24,11 @@
 #include <QMouseEvent>
 #include <QWheelEvent>
 #include <QContextMenuEvent>
+#ifndef Q_MOC_RUN
 #include <boost/lambda/lambda.hpp>
 #include <boost/lambda/construct.hpp>
 #include <boost/lambda/bind.hpp>
+#endif
 #include <assert.h>
 
 #define DISPATCH(list, call) {                    \
--- scantailor-0.9.11.1/interaction/InteractionHandler.h
+++ scantailor-0.9.11.1/interaction/InteractionHandler.h
@@ -22,7 +22,9 @@
 #include "NonCopyable.h"
 #include "RefCountable.h"
 #include "IntrusivePtr.h"
+#ifndef Q_MOC_RUN
 #include <boost/intrusive/list.hpp>
+#endif
 
 class InteractionState;
 class QPainter;
--- scantailor-0.9.11.1/interaction/InteractionState.h
+++ scantailor-0.9.11.1/interaction/InteractionState.h
@@ -21,7 +21,9 @@
 
 #include "NonCopyable.h"
 #include "Proximity.h"
+#ifndef Q_MOC_RUN
 #include <boost/intrusive/list.hpp>
+#endif
 #include <QCursor>
 #include <QString>
 
--- scantailor-0.9.11.1/interaction/InteractiveXSpline.cpp
+++ scantailor-0.9.11.1/interaction/InteractiveXSpline.cpp
@@ -23,7 +23,9 @@
 #include <QCursor>
 #include <QMouseEvent>
 #include <Qt>
+#ifndef Q_MOC_RUN
 #include <boost/bind.hpp>
+#endif
 
 struct InteractiveXSpline::NoOp
 {
--- scantailor-0.9.11.1/interaction/InteractiveXSpline.h
+++ scantailor-0.9.11.1/interaction/InteractiveXSpline.h
@@ -26,8 +26,10 @@
 #include "VecNT.h"
 #include <QPointF>
 #include <QCoreApplication>
+#ifndef Q_MOC_RUN
 #include <boost/function.hpp>
 #include <boost/scoped_array.hpp>
+#endif
 #include <stddef.h>
 
 class InteractiveXSpline : public InteractionHandler
--- scantailor-0.9.11.1/interaction/ZoomHandler.h
+++ scantailor-0.9.11.1/interaction/ZoomHandler.h
@@ -23,7 +23,9 @@
 #include "InteractionState.h"
 #include <QPoint>
 #include <QCoreApplication>
+#ifndef Q_MOC_RUN
 #include <boost/function.hpp>
+#endif
 
 class ImageViewBase;
 
--- scantailor-0.9.11.1/LoadFilesStatusDialog.cpp
+++ scantailor-0.9.11.1/LoadFilesStatusDialog.cpp
@@ -18,7 +18,9 @@
 
 #include "LoadFilesStatusDialog.h"
 #include <QPushButton>
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
+#endif
 
 LoadFilesStatusDialog::LoadFilesStatusDialog(QWidget* parent)
 :	QDialog(parent)
--- scantailor-0.9.11.1/MainWindow.cpp
+++ scantailor-0.9.11.1/MainWindow.cpp
@@ -91,9 +91,11 @@
 #include "ui_BatchProcessingLowerPanel.h"
 #include "config.h"
 #include "version.h"
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
 #include <boost/lambda/lambda.hpp>
 #include <boost/lambda/bind.hpp>
+#endif
 #include <QApplication>
 #include <QLineF>
 #include <QPointer>
--- scantailor-0.9.11.1/MainWindow.h
+++ scantailor-0.9.11.1/MainWindow.h
@@ -33,7 +33,9 @@
 #include "PageRange.h"
 #include "SelectedPage.h"
 #include "BeforeOrAfter.h"
+#ifndef Q_MOC_RUN
 #include <boost/function.hpp>
+#endif
 #include <QMainWindow>
 #include <QString>
 #include <QPointer>
--- scantailor-0.9.11.1/math/adiff/tests/TestHessians.cpp
+++ scantailor-0.9.11.1/math/adiff/tests/TestHessians.cpp
@@ -20,8 +20,10 @@
 #include "SparseMap.h"
 #include "MatT.h"
 #include "VecT.h"
+#ifndef Q_MOC_RUN
 #include <boost/test/auto_unit_test.hpp>
 #include <boost/test/floating_point_comparison.hpp>
+#endif
 #include <stdlib.h>
 #include <math.h>
 
--- scantailor-0.9.11.1/math/ArcLengthMapper.cpp
+++ scantailor-0.9.11.1/math/ArcLengthMapper.cpp
@@ -17,7 +17,9 @@
 */
 
 #include "ArcLengthMapper.h"
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
+#endif
 #include <math.h>
 #include <assert.h>
 
--- scantailor-0.9.11.1/math/LinearSolver.h
+++ scantailor-0.9.11.1/math/LinearSolver.h
@@ -25,7 +25,9 @@
 #include <limits>
 #include <stdexcept>
 #include <string>
+#ifndef Q_MOC_RUN
 #include <boost/scoped_array.hpp>
+#endif
 #include <stddef.h>
 #include <assert.h>
 
--- scantailor-0.9.11.1/math/LineBoundedByRect.cpp
+++ scantailor-0.9.11.1/math/LineBoundedByRect.cpp
@@ -19,7 +19,9 @@
 #include "LineBoundedByRect.h"
 #include "LineIntersectionScalar.h"
 #include "NumericTraits.h"
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
+#endif
 
 bool lineBoundedByRect(QLineF& line, QRectF const& rect)
 {
--- scantailor-0.9.11.1/math/spfit/ConstraintSet.cpp
+++ scantailor-0.9.11.1/math/spfit/ConstraintSet.cpp
@@ -18,7 +18,9 @@
 
 #include "ConstraintSet.h"
 #include "FittableSpline.h"
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
+#endif
 #include <assert.h>
 
 namespace spfit
--- scantailor-0.9.11.1/math/spfit/Optimizer.cpp
+++ scantailor-0.9.11.1/math/spfit/Optimizer.cpp
@@ -18,7 +18,9 @@
 
 #include "Optimizer.h"
 #include "MatrixCalc.h"
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
+#endif
 #include <stdexcept>
 #include <algorithm>
 #include <assert.h>
--- scantailor-0.9.11.1/math/spfit/PolylineModelShape.cpp
+++ scantailor-0.9.11.1/math/spfit/PolylineModelShape.cpp
@@ -23,7 +23,9 @@
 #include "VecNT.h"
 #include "ToLineProjector.h"
 #include <QDebug>
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
+#endif
 #include <stdexcept>
 #include <limits>
 #include <math.h>
--- scantailor-0.9.11.1/math/spfit/SplineFitter.cpp
+++ scantailor-0.9.11.1/math/spfit/SplineFitter.cpp
@@ -22,7 +22,9 @@
 #include "ConstraintSet.h"
 #include "ModelShape.h"
 #include "VirtualFunction.h"
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
+#endif
 #include <stdexcept>
 
 namespace spfit
--- scantailor-0.9.11.1/math/spfit/tests/TestSqDistApproximant.cpp
+++ scantailor-0.9.11.1/math/spfit/tests/TestSqDistApproximant.cpp
@@ -21,8 +21,10 @@
 #include "ToLineProjector.h"
 #include <QPointF>
 #include <QLineF>
+#ifndef Q_MOC_RUN
 #include <boost/test/auto_unit_test.hpp>
 #include <boost/test/floating_point_comparison.hpp>
+#endif
 #include <stdlib.h>
 #include <math.h>
 
--- scantailor-0.9.11.1/math/XSpline.cpp
+++ scantailor-0.9.11.1/math/XSpline.cpp
@@ -25,7 +25,9 @@
 #include "adiff/Function.h"
 #include <QLineF>
 #include <QDebug>
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
+#endif
 #include <string>
 #include <stdexcept>
 #include <algorithm>
--- scantailor-0.9.11.1/NewOpenProjectPanel.cpp
+++ scantailor-0.9.11.1/NewOpenProjectPanel.cpp
@@ -19,8 +19,10 @@
 #include "NewOpenProjectPanel.h.moc"
 #include "RecentProjects.h"
 #include "Utils.h"
+#ifndef Q_MOC_RUN
 #include <boost/lambda/lambda.hpp>
 #include <boost/lambda/bind.hpp>
+#endif
 #include <QVBoxLayout>
 #include <QPainter>
 #include <QPalette>
--- scantailor-0.9.11.1/NonOwningWidget.cpp
+++ scantailor-0.9.11.1/NonOwningWidget.cpp
@@ -17,7 +17,9 @@
 */
 
 #include "NonOwningWidget.h"
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
+#endif
 
 NonOwningWidget::NonOwningWidget(QWidget* parent)
 :	QWidget(parent)
--- scantailor-0.9.11.1/OutOfMemoryHandler.h
+++ scantailor-0.9.11.1/OutOfMemoryHandler.h
@@ -22,7 +22,9 @@
 #include "NonCopyable.h"
 #include <QObject>
 #include <QMutex>
+#ifndef Q_MOC_RUN
 #include <boost/scoped_array.hpp>
+#endif
 #include <stddef.h>
 
 class OutOfMemoryHandler : public QObject
--- scantailor-0.9.11.1/PageRange.cpp
+++ scantailor-0.9.11.1/PageRange.cpp
@@ -17,7 +17,9 @@
 */
 
 #include "PageRange.h"
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
+#endif
 
 std::set<PageId>
 PageRange::selectEveryOther(PageId const& base) const
--- scantailor-0.9.11.1/PageSequence.cpp
+++ scantailor-0.9.11.1/PageSequence.cpp
@@ -17,7 +17,9 @@
 */
 
 #include "PageSequence.h"
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
+#endif
 
 void
 PageSequence::append(PageInfo const& page_info)
--- scantailor-0.9.11.1/ProcessingTaskQueue.cpp
+++ scantailor-0.9.11.1/ProcessingTaskQueue.cpp
@@ -17,7 +17,9 @@
 */
 
 #include "ProcessingTaskQueue.h"
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
+#endif
 
 ProcessingTaskQueue::Entry::Entry(
 	PageInfo const& page_info, BackgroundTaskPtr const& tsk)
--- scantailor-0.9.11.1/ProjectCreationContext.cpp
+++ scantailor-0.9.11.1/ProjectCreationContext.cpp
@@ -22,8 +22,10 @@
 #include "ImageFileInfo.h"
 #include <QString>
 #include <Qt>
+#ifndef Q_MOC_RUN
 #include <boost/lambda/lambda.hpp>
 #include <boost/lambda/bind.hpp>
+#endif
 #include <algorithm>
 #include <assert.h>
 
--- scantailor-0.9.11.1/ProjectFilesDialog.cpp
+++ scantailor-0.9.11.1/ProjectFilesDialog.cpp
@@ -40,9 +40,11 @@
 #include <QBrush>
 #include <QColor>
 #include <QDebug>
+#ifndef Q_MOC_RUN
 #include <boost/lambda/lambda.hpp>
 #include <boost/lambda/bind.hpp>
 #include <boost/lambda/construct.hpp>
+#endif
 #include <vector>
 #include <deque>
 #include <algorithm>
--- scantailor-0.9.11.1/ProjectOpeningContext.cpp
+++ scantailor-0.9.11.1/ProjectOpeningContext.cpp
@@ -23,8 +23,10 @@
 #include <QString>
 #include <QMessageBox>
 #include <Qt>
+#ifndef Q_MOC_RUN
 #include <boost/lambda/lambda.hpp>
 #include <boost/lambda/bind.hpp>
+#endif
 #include <algorithm>
 #include <assert.h>
 
--- scantailor-0.9.11.1/ProjectPages.cpp
+++ scantailor-0.9.11.1/ProjectPages.cpp
@@ -25,11 +25,13 @@
 #include "PageSequence.h"
 #include "RelinkablePath.h"
 #include "AbstractRelinker.h"
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
 #include <boost/multi_index_container.hpp>
 #include <boost/multi_index/ordered_index.hpp>
 #include <boost/multi_index/sequenced_index.hpp>
 #include <boost/multi_index/member.hpp>
+#endif
 #include <QMutexLocker>
 #include <QFileInfo>
 #include <QSize>
--- scantailor-0.9.11.1/ProjectReader.cpp
+++ scantailor-0.9.11.1/ProjectReader.cpp
@@ -26,7 +26,9 @@
 #include <QDir>
 #include <QDomElement>
 #include <QDomNode>
+#ifndef Q_MOC_RUN
 #include <boost/bind.hpp>
+#endif
 #include <set>
 
 ProjectReader::ProjectReader(QDomDocument const& doc)
--- scantailor-0.9.11.1/ProjectWriter.cpp
+++ scantailor-0.9.11.1/ProjectWriter.cpp
@@ -30,8 +30,10 @@
 #include <QFile>
 #include <QTextStream>
 #include <QFileInfo>
+#ifndef Q_MOC_RUN
 #include <boost/bind.hpp>
 #include <boost/foreach.hpp>
+#endif
 #include <stddef.h>
 #include <assert.h>
 
--- scantailor-0.9.11.1/ProjectWriter.h
+++ scantailor-0.9.11.1/ProjectWriter.h
@@ -26,10 +26,12 @@
 #include "PageId.h"
 #include "SelectedPage.h"
 #include "VirtualFunction.h"
+#ifndef Q_MOC_RUN
 #include <boost/multi_index_container.hpp>
 #include <boost/multi_index/sequenced_index.hpp>
 #include <boost/multi_index/ordered_index.hpp>
 #include <boost/multi_index/member.hpp>
+#endif
 #include <QString>
 #include <Qt>
 #include <vector>
--- scantailor-0.9.11.1/RecentProjects.cpp
+++ scantailor-0.9.11.1/RecentProjects.cpp
@@ -17,7 +17,9 @@
 */
 
 #include "RecentProjects.h"
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
+#endif
 #include <QSettings>
 #include <QFile>
 #include <algorithm>
--- scantailor-0.9.11.1/RelinkablePath.cpp
+++ scantailor-0.9.11.1/RelinkablePath.cpp
@@ -18,7 +18,9 @@
 
 #include "RelinkablePath.h"
 #include <QStringList>
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
+#endif
 
 RelinkablePath::RelinkablePath(QString const& path, Type type)
 :	m_normalizedPath(normalize(path))
--- scantailor-0.9.11.1/RelinkablePathVisualization.cpp
+++ scantailor-0.9.11.1/RelinkablePathVisualization.cpp
@@ -33,8 +33,10 @@
 #include <QStyleOptionButton>
 #include <QFile>
 #include <QVariant>
+#ifndef Q_MOC_RUN
 #include <boost/bind.hpp>
 #include <boost/foreach.hpp>
+#endif
 #include <vector>
 
 struct RelinkablePathVisualization::PathComponent
--- scantailor-0.9.11.1/RelinkingDialog.cpp
+++ scantailor-0.9.11.1/RelinkingDialog.cpp
@@ -22,7 +22,9 @@
 #include <QDir>
 #include <QFileDialog>
 #include <QDebug>
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
+#endif
 #include <assert.h>
 
 RelinkingDialog::RelinkingDialog(QString const& project_file_path, QWidget* parent)
--- scantailor-0.9.11.1/RelinkingListView.cpp
+++ scantailor-0.9.11.1/RelinkingListView.cpp
@@ -27,7 +27,9 @@
 #include <QBrush>
 #include <QColor>
 #include <QVariant>
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
+#endif
 #include <vector>
 
 class RelinkingListView::Delegate : public QStyledItemDelegate
--- scantailor-0.9.11.1/RelinkingModel.cpp
+++ scantailor-0.9.11.1/RelinkingModel.cpp
@@ -27,11 +27,13 @@
 #include <QCoreApplication>
 #include <QColor>
 #include <Qt>
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
 #include <boost/multi_index_container.hpp>
 #include <boost/multi_index/ordered_index.hpp>
 #include <boost/multi_index/sequenced_index.hpp>
 #include <boost/multi_index/member.hpp>
+#endif
 #include <utility>
 #include <iterator>
 #include <algorithm>
--- scantailor-0.9.11.1/StageListView.cpp
+++ scantailor-0.9.11.1/StageListView.cpp
@@ -36,7 +36,9 @@
 #include <QVariant>
 #include <Qt>
 #include <QDebug>
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
+#endif
 #include <algorithm>
 #include <memory>
 #include <assert.h>
--- scantailor-0.9.11.1/StageSequence.cpp
+++ scantailor-0.9.11.1/StageSequence.cpp
@@ -18,7 +18,9 @@
 
 #include "StageSequence.h"
 #include "ProjectPages.h"
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
+#endif
 
 StageSequence::StageSequence(IntrusivePtr<ProjectPages> const& pages,
 	PageSelectionAccessor const& page_selection_accessor)
--- scantailor-0.9.11.1/TabbedDebugImages.h
+++ scantailor-0.9.11.1/TabbedDebugImages.h
@@ -21,7 +21,9 @@
 
 #include "DebugImageView.h"
 #include <QTabWidget>
+#ifndef Q_MOC_RUN
 #include <boost/intrusive/list.hpp>
+#endif
 
 class TabbedDebugImages : public QTabWidget
 {
--- scantailor-0.9.11.1/tests/main.cpp
+++ scantailor-0.9.11.1/tests/main.cpp
@@ -22,4 +22,6 @@
 
 #define BOOST_AUTO_TEST_MAIN
 
+#ifndef Q_MOC_RUN
 #include <boost/test/auto_unit_test.hpp>
+#endif
--- scantailor-0.9.11.1/tests/TestContentSpanFinder.cpp
+++ scantailor-0.9.11.1/tests/TestContentSpanFinder.cpp
@@ -20,9 +20,11 @@
 #include "imageproc/SlicedHistogram.h"
 #include "Span.h"
 #include <vector>
+#ifndef Q_MOC_RUN
 #include <boost/lambda/lambda.hpp>
 #include <boost/lambda/bind.hpp>
 #include <boost/test/auto_unit_test.hpp>
+#endif
 
 namespace Tests
 {
--- scantailor-0.9.11.1/tests/TestMatrixCalc.cpp
+++ scantailor-0.9.11.1/tests/TestMatrixCalc.cpp
@@ -17,8 +17,10 @@
 */
 
 #include "MatrixCalc.h"
+#ifndef Q_MOC_RUN
 #include <boost/test/auto_unit_test.hpp>
 #include <boost/test/floating_point_comparison.hpp>
+#endif
 
 namespace imageproc
 {
--- scantailor-0.9.11.1/tests/TestSmartFilenameOrdering.cpp
+++ scantailor-0.9.11.1/tests/TestSmartFilenameOrdering.cpp
@@ -19,7 +19,9 @@
 #include "SmartFilenameOrdering.h"
 #include <QFileInfo>
 #include <QString>
+#ifndef Q_MOC_RUN
 #include <boost/test/auto_unit_test.hpp>
+#endif
 
 namespace Tests
 {
--- scantailor-0.9.11.1/ThumbnailBase.cpp
+++ scantailor-0.9.11.1/ThumbnailBase.cpp
@@ -23,7 +23,9 @@
 #include "AbstractCommand.h"
 #include "PixmapRenderer.h"
 #include "imageproc/PolygonUtils.h"
+#ifndef Q_MOC_RUN
 #include <boost/weak_ptr.hpp>
+#endif
 #include <QPixmap>
 #include <QPixmapCache>
 #include <QPainter>
--- scantailor-0.9.11.1/ThumbnailBase.h
+++ scantailor-0.9.11.1/ThumbnailBase.h
@@ -24,7 +24,9 @@
 #include "ImageTransformation.h"
 #include "IntrusivePtr.h"
 #include "ThumbnailPixmapCache.h"
+#ifndef Q_MOC_RUN
 #include <boost/shared_ptr.hpp>
+#endif
 #include <QTransform>
 #include <QGraphicsItem>
 #include <QSizeF>
--- scantailor-0.9.11.1/ThumbnailPixmapCache.cpp
+++ scantailor-0.9.11.1/ThumbnailPixmapCache.cpp
@@ -39,11 +39,13 @@
 #include <QEvent>
 #include <QSize>
 #include <QDebug>
+#ifndef Q_MOC_RUN
 #include <boost/multi_index_container.hpp>
 #include <boost/multi_index/ordered_index.hpp>
 #include <boost/multi_index/sequenced_index.hpp>
 #include <boost/multi_index/member.hpp>
 #include <boost/foreach.hpp>
+#endif
 #include <algorithm>
 #include <vector>
 #include <new>
--- scantailor-0.9.11.1/ThumbnailPixmapCache.h
+++ scantailor-0.9.11.1/ThumbnailPixmapCache.h
@@ -23,7 +23,9 @@
 #include "RefCountable.h"
 #include "ThumbnailLoadResult.h"
 #include "AbstractCommand.h"
+#ifndef Q_MOC_RUN
 #include <boost/weak_ptr.hpp>
+#endif
 #include <memory>
 
 class ImageId;
--- scantailor-0.9.11.1/ThumbnailSequence.cpp
+++ scantailor-0.9.11.1/ThumbnailSequence.cpp
@@ -28,6 +28,7 @@
 #include "RefCountable.h"
 #include "IntrusivePtr.h"
 #include "ScopedIncDec.h"
+#ifndef Q_MOC_RUN
 #include <boost/multi_index_container.hpp>
 #include <boost/multi_index/ordered_index.hpp>
 #include <boost/multi_index/sequenced_index.hpp>
@@ -36,6 +37,7 @@
 #include <boost/lambda/lambda.hpp>
 #include <boost/lambda/bind.hpp>
 #include <boost/foreach.hpp>
+#endif
 #include <QGraphicsScene>
 #include <QGraphicsItem>
 #include <QGraphicsItemGroup>
--- scantailor-0.9.11.1/XmlMarshaller.cpp
+++ scantailor-0.9.11.1/XmlMarshaller.cpp
@@ -21,7 +21,9 @@
 #include "Margins.h"
 #include "Dpi.h"
 #include "Utils.h"
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
+#endif
 #include <QPointF>
 #include <QLineF>
 #include <QRect>
--- scantailor-0.9.11.1/zones/BasicSplineVisualizer.cpp
+++ scantailor-0.9.11.1/zones/BasicSplineVisualizer.cpp
@@ -21,7 +21,9 @@
 #include <QPainter>
 #include <QBrush>
 #include <Qt>
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
+#endif
 
 BasicSplineVisualizer::BasicSplineVisualizer()
 :	m_solidColor(0xcc1420),
--- scantailor-0.9.11.1/zones/EditableSpline.cpp
+++ scantailor-0.9.11.1/zones/EditableSpline.cpp
@@ -22,7 +22,9 @@
 #include <QDomNode>
 #include <QDomElement>
 #include <QString>
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
+#endif
 #include <assert.h>
 
 EditableSpline::EditableSpline()
--- scantailor-0.9.11.1/zones/EditableZoneSet.h
+++ scantailor-0.9.11.1/zones/EditableZoneSet.h
@@ -24,9 +24,11 @@
 #include "PropertySet.h"
 #include "IntrusivePtr.h"
 #include <QObject>
+#ifndef Q_MOC_RUN
 #include <boost/mpl/bool.hpp>
 #include <boost/foreach.hpp>
 #include <boost/iterator/iterator_facade.hpp>
+#endif
 #include <map>
 
 class EditableZoneSet : public QObject
--- scantailor-0.9.11.1/zones/SerializableSpline.cpp
+++ scantailor-0.9.11.1/zones/SerializableSpline.cpp
@@ -26,7 +26,9 @@
 #include <QTransform>
 #include <QString>
 #include <QPointF>
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
+#endif
 
 SerializableSpline::SerializableSpline(EditableSpline const& spline)
 {
--- scantailor-0.9.11.1/zones/SerializableSpline.h
+++ scantailor-0.9.11.1/zones/SerializableSpline.h
@@ -22,7 +22,9 @@
 #include <QVector>
 #include <QPointF>
 #include <QPolygonF>
+#ifndef Q_MOC_RUN
 #include <boost/function.hpp>
+#endif
 
 class EditableSpline;
 class QTransform;
--- scantailor-0.9.11.1/zones/ZoneContextMenuInteraction.cpp
+++ scantailor-0.9.11.1/zones/ZoneContextMenuInteraction.cpp
@@ -33,9 +33,11 @@
 #include <QCursor>
 #include <QMessageBox>
 #include <QDebug>
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
 #include <boost/bind.hpp>
 #include <boost/ref.hpp>
+#endif
 #include <vector>
 #include <assert.h>
 
--- scantailor-0.9.11.1/zones/ZoneContextMenuInteraction.h
+++ scantailor-0.9.11.1/zones/ZoneContextMenuInteraction.h
@@ -30,7 +30,9 @@
 #include <QObject>
 #include <QColor>
 #include <QtGlobal>
+#ifndef Q_MOC_RUN
 #include <boost/function.hpp>
+#endif
 #include <map>
 #include <memory>
 #include <vector>
--- scantailor-0.9.11.1/zones/ZoneContextMenuItem.h
+++ scantailor-0.9.11.1/zones/ZoneContextMenuItem.h
@@ -20,7 +20,9 @@
 #define ZONE_CONTEXT_MENU_ITEM_H_
 
 #include <QString>
+#ifndef Q_MOC_RUN
 #include <boost/function.hpp>
+#endif
 
 class InteractionState;
 class InteractionHandler;
--- scantailor-0.9.11.1/zones/ZoneCreationInteraction.cpp
+++ scantailor-0.9.11.1/zones/ZoneCreationInteraction.cpp
@@ -30,7 +30,9 @@
 #include <Qt>
 #include <QLineF>
 #include <QDebug>
+#ifndef Q_MOC_RUN
 #include <boost/lambda/lambda.hpp>
+#endif
 
 ZoneCreationInteraction::ZoneCreationInteraction(
 	ZoneInteractionContext& context, InteractionState& interaction)
--- scantailor-0.9.11.1/zones/ZoneDefaultInteraction.cpp
+++ scantailor-0.9.11.1/zones/ZoneDefaultInteraction.cpp
@@ -30,7 +30,9 @@
 #include <QLinearGradient>
 #include <Qt>
 #include <QMouseEvent>
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
+#endif
 #include <vector>
 #include <assert.h>
 
--- scantailor-0.9.11.1/zones/ZoneInteractionContext.cpp
+++ scantailor-0.9.11.1/zones/ZoneInteractionContext.cpp
@@ -21,7 +21,9 @@
 #include "ZoneCreationInteraction.h"
 #include "ZoneVertexDragInteraction.h"
 #include "ZoneContextMenuInteraction.h"
+#ifndef Q_MOC_RUN
 #include <boost/bind.hpp>
+#endif
 
 ZoneInteractionContext::ZoneInteractionContext(
 	ImageViewBase& image_view, EditableZoneSet& zones)
--- scantailor-0.9.11.1/zones/ZoneInteractionContext.h
+++ scantailor-0.9.11.1/zones/ZoneInteractionContext.h
@@ -22,7 +22,9 @@
 #include "EditableSpline.h"
 #include "SplineVertex.h"
 #include "EditableZoneSet.h"
+#ifndef Q_MOC_RUN
 #include <boost/function.hpp>
+#endif
 
 class InteractionHandler;
 class InteractionState;
--- scantailor-0.9.11.1/zones/ZoneSet.cpp
+++ scantailor-0.9.11.1/zones/ZoneSet.cpp
@@ -21,7 +21,9 @@
 #include <QDomDocument>
 #include <QDomElement>
 #include <QString>
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
+#endif
 
 ZoneSet::ZoneSet(QDomElement const& el, PropertyFactory const& prop_factory)
 {
--- scantailor-0.9.11.1/zones/ZoneSet.h
+++ scantailor-0.9.11.1/zones/ZoneSet.h
@@ -20,7 +20,9 @@
 #define ZONE_SET_H_
 
 #include "Zone.h"
+#ifndef Q_MOC_RUN
 #include <boost/iterator/iterator_facade.hpp>
+#endif
 #include <list>
 
 class PropertyFactory;
--- scantailor-0.9.11.1/zones/ZoneVertexDragInteraction.cpp
+++ scantailor-0.9.11.1/zones/ZoneVertexDragInteraction.cpp
@@ -27,7 +27,9 @@
 #include <QLinearGradient>
 #include <Qt>
 #include <QLineF>
+#ifndef Q_MOC_RUN
 #include <boost/foreach.hpp>
+#endif
 
 ZoneVertexDragInteraction::ZoneVertexDragInteraction(
 	ZoneInteractionContext& context, InteractionState& interaction,
